/*
 * Copyright (c) 2006 AWS Convergence Technologies, Inc. 
 * All rights reserved.
 * Visit http://www.aws.com
 *
 * WBLiveData.js
 *
 * This scripts contains the WBLiveData resuable class. A LiveData object takes care of
 * loading and holding data from the GetData60 ISAPI.
 */

// Object Definition
function WBLiveData(loadCallback,errorCallback,errorString,shortErrorWaitTime,longErrorWaitTime,URL,preferences,minUpdateRate,maxUpdateRate,widgetState)
{
	this.time = new WBTime(); // New time object
	this.lastReload; // Last time the data was successfully updated
	this.minUpdateRate = minUpdateRate; // Rate at which the data should be updated in miliseconds (minimum bound)
	this.maxUpdateRate = maxUpdateRate; // Rate at which the data should be updated in miliseconds (maximum bound)
	
	this.temperature;   // Current Temperature (In Degrees)
	this.location;      // Current Location (City, State)
	this.source;        // Current Data Source
	this.windspeed;     // Wind Speed (in mph)
	this.winddirection; // Wind Direction (0 to 360 degrees)
	this.prefs = preferences; // Holds the current WBPrefernces object

	// WBDataRequest object. Does the work in loading data from the ISAPI.
	this.data = new WBTextDataRequest(URL + '&magic=10991',this.dataFetched,errorCallback);

	this.loadCallback = loadCallback;		      // Data Loaded Callback
	this.loadErrorCallback = errorCallback;       // Data Error Callback
	this.errorString = errorString;               // String passed to the reload timer
	this.shortErrorWaitTime = shortErrorWaitTime; // Timeout for short error
	this.longErrorWaitTime = longErrorWaitTime;   // Timeout for long error
	this.errorCount = 0;                          // Counts the number of internal loading errors
	this.dataLoadedCorrectly = false;             // BOOL to see if we have correct data in the object or not
	
	this.widgetState = widgetState;
	
	this.dataFetched.currentScope = this; // Used when the dataFetched function has lost scope.
}

// Do not call this directly, only from an initialized WBLiveData object.
// Used to reload current information in the WBLiveData object.
WBLiveData.prototype.load = function () {
	if(this.errorCount > 2)
	{
		this.errorCount = 0;
		this.loadErrorCallback(this.errorString,this.longErrorWaitTime);
		this.dataLoadedCorrectly = false;
		return;
	}
	
	// Check to see if we are allowed to reload the object based on the update rate.
	// state = 1 uses the active min update rate
	// otherwise use the max update rate
	if(this.widgetState.state)
	{
		if(this.time.checkForUpdate(this.lastReload,this.minUpdateRate)) { this.data.load("&ZipCode=" + this.prefs.getZipCode() + "&StationID=" + this.prefs.getStationID() + "&Units=" + this.prefs.getUnits() + "&Fore=0"); }
	}
	else
	{
		if(this.time.checkForUpdate(this.lastReload,this.maxUpdateRate)) { this.data.load("&ZipCode=" + this.prefs.getZipCode() + "&StationID=" + this.prefs.getStationID() + "&Units=" + this.prefs.getUnits() + "&Fore=0"); }
	}
}

// Do not call this directly, only from an initialized WBLiveData object.
// Reloads the data without checking for update rates.
WBLiveData.prototype.superReload = function () {
	this.data.load("&ZipCode=" + this.prefs.getZipCode() + "&StationID=" + this.prefs.getStationID() + "&Units=" + this.prefs.getUnits()  + "Fore=0");
}

// Do not call this directly, only from an initialized WBLiveData object.
// Used to parse the information from the WBDataRequest object into the object variables.
WBLiveData.prototype.dataFetched = function ()
{
	// make sure 'this' is in scope, if not call it again with the correct scope
    if(this != arguments.callee.currentScope){ return arguments.callee.apply(arguments.callee.currentScope, arguments); };

	try
	{
		var liveDataArray = this.data.request.responseText.split("|");
	
		if(liveDataArray[0] == 10991) // Simple Error Validation
		{
			//this.updateRate = liveDataArray[40];

			this.temperature = Math.round(liveDataArray[3]);
			this.winddirection = parseInt(liveDataArray[4]);		
			this.location = liveDataArray[37].replace(", WORLD","");
			this.source = liveDataArray[35];
			if(liveDataArray[36] != "")
			{
				this.source = this.source + " " + liveDataArray[36];
			}
			if(liveDataArray[5] == "N/A" || liveDataArray[5] == "NA"){ liveDataObj.windspeed = '--'; }
			else { this.windspeed = liveDataArray[5]; }
		}
		else {
			this.errorCount++;
			this.loadErrorCallback(this.errorString,this.shortErrorWaitTime);
			this.dataLoadedCorrectly = false;
			return;
		}
	}
	catch(e)
	{
		this.errorCount++;
		this.loadErrorCallback(this.errorString,this.shortErrorWaitTime);
		this.dataLoadedCorrectly = false;
		return;
	}
	this.dataLoadedCorrectly = true;
	this.lastReload = this.time.currentTime();
	this.loadCallback();
}
