/*
 * Copyright (c) 2006 AWS Convergence Technologies, Inc. 
 * All rights reserved.
 * Visit http://www.aws.com
 *
 * main.js
 *
 * This script contains the core of the widget, object declarations, callback
 * functions, etc.
 */
 
// Global Object Variables
var button_bar;
var back_button_bar;
var back_progress_animator;
var drawer_stretch;
var back_stretch;
var design, widgetPrefs, liveDataObj, stationsDataObj, cameraDataObj, forecastDataObj, radarDataObj, alertsDataObj, moreContentObj;
var scrollbar, scrollArea;
var glassbutton;
var notifiedofupdate = false;
var bugStateObj;
var globalTimeoutTimer;
var designReloadTimer;
var ZCode = 'Z5468';
var version = '1.1.0.10';
var vaneObj;
var activeAlertsNumber = 0;
var dashHidden = false;

// Called when index.html has successfully loaded. Widget javascript execution starts here.
function setup_widget()
{
	// make sure that we are running in Dashboard, and not a web browser by verifying window.widget exists
	if (window.widget)
	{
		drawer_stretch = new WBDrawer(document.getElementById('front'),500);// The expanding drawer element of the widget
		button_bar = new WBButtonBar(document.getElementById('forecast_container'),document.getElementById('forecast_button_image'),document.getElementById('radar_container'),document.getElementById('radar_button_image'),document.getElementById('cams_container'),document.getElementById('cams_button_image'),document.getElementById('more_container'),document.getElementById('more_button_image'),drawer_stretch,drawer_container); // Four buttons on the front of the widget that control the drawer
		widgetPrefs = new WBPreferences(); // Create and initialize new WBPreferences Object
		button_bar.changeType(widgetPrefs.getType());
		design = new WBDataLocations(designLoaded,dataLoadingError,'design.load()',20000,1800000,"http://macdash.ext.weatherbug.com/DataService/GetCommand_v2.aspx",widgetPrefs,version); // Create a new DataLocations Object
		design.load(); // Begin loading of support URLs
		version_number.innerHTML = version;
		widget.setPreferenceForKey(version,"CurrentVersion");
	}
}

// design Successful Load Callback
function designLoaded()
{
	if(designReloadTimer){
		clearTimeout(designReloadTimer);
	}
	designReloadTimer = setTimeout('design.load()',design.updateRate);

	if(!stationsDataObj){
		stationsDataObj = new WBStations(design.locationURL + '?ss=',design.stationURL + '?un=0',citiesLoaded,citiesLoadedError,stationsLoaded,stationsLoadedError);
	}
	if((widgetPrefs.getZipCode() || widgetPrefs.getCountryName()) && ((design.newVersionAvailable == 0 && widgetPrefs.getNotifyForUpdates() == true) || widgetPrefs.getNotifyForUpdates() == false || notifiedofupdate == true)){
		if(bugStateObj) { delete bugStateObj; }
		bugStateObj = new WBState(new Array(design.forecastMinUpdateRate,design.radarMinUpdateRate,design.alertsMinUpdateRate,design.liveMinUpdateRate),new Array(design.forecastMaxUpdateRate,design.radarMaxUpdateRate,design.alertsMaxUpdateRate,design.liveMaxUpdateRate),design.stateswitchtimer);

		//Create the objects that hold all the WeatherBug Data
		if(liveDataObj) { delete liveDataObj; }
		liveDataObj = new WBLiveData(liveDataLoaded,dataLoadingError,'liveDataObj.load()',design.dataErrorShortWaitTime,design.dataErrorLongWaitTime,design.liveDataURL,widgetPrefs,design.liveMinUpdateRate,design.liveMaxUpdateRate,bugStateObj); // Create a new LiveData Object
		if(moreContentObj) { delete moreContentObj; }
		moreContentObj = new WBMoreTabData(moreTabDataLoaded,dataLoadingError,'moreContentObj.load()',design.dataErrorShortWaitTime,design.dataErrorLongWaitTime,design.moreTabContentURL,widgetPrefs,design.moreTabMinUpdateRate,design.moreTabMaxUpdateRate,bugStateObj);
		if(vaneObj){ delete vaneObj; }
		vaneObj = new WBVaneAnimator(document.getElementById("vane_canvas"),500);
		if(forecastDataObj) { delete forecastDataObj; }
		forecastDataObj = new WBForecastData(forecastDataLoaded,dataLoadingError,'forecastDataObj.load()',design.dataErrorShortWaitTime,design.dataErrorLongWaitTime,design.forecastDataURL,widgetPrefs,design.pid,design.forecastMinUpdateRate,design.forecastMaxUpdateRate,bugStateObj); // Create a new ForecastData Object
		if(radarDataObj) { delete radarDataObj; }
		radarDataObj = new WBRadarData(radarDataLoaded,dataLoadingError,'radarDataObj.load()',design.dataErrorShortWaitTime,design.dataErrorLongWaitTime,design.radarDataURL,widgetPrefs,design.pid,design.radarMinUpdateRate,design.radarMaxUpdateRate,bugStateObj); // Create a new RadarData Object	
		if(alertsDataObj) { delete alertsDataObj; }
		alertsDataObj = new WBAlertsData(alertsDataLoaded,dataLoadingError,'alertsDataObj.load()',design.dataErrorShortWaitTime,design.dataErrorLongWaitTime,design.alertsDataURL,widgetPrefs,design.pid,design.alertsMinUpdateRate,design.alertsMaxUpdateRate,bugStateObj); // Create a new AlertsData Object
		if(cameraDataObj) { delete cameraDataObj }
		cameraDataObj = new WBCameraData(cameraDataLoaded,dataLoadingError,'cameraDataObj.load()',design.dataErrorShortWaitTime,design.dataErrorLongWaitTime,design.camsDataURL,widgetPrefs,design.pid,design.camsMinUpdateRate,design.camsMaxUpdateRate,bugStateObj); // Create Camera Obj
		bugStateObj.setAllObjects(new Array(liveDataObj,forecastDataObj,radarDataObj,alertsDataObj,cameraDataObj,moreContentObj));
		widget.onshow = onShow;
		widget.onhide = onHide;
		bugStateObj.setSuperReload();
	}
	else
	{
		shrinkAndShowBack(); // Show the widget prefs so we can get a zip code and create the design URLS	
	}
}

function moreTabDataLoaded()
{
	more_container.innerHTML = moreContentObj.tabContentArray[0];
	button_bar.setMoreTabHeight(moreContentObj.tabHeightArray[0]);
	
	if(moreContentObj.tabContentArray[1] != null && moreContentObj.tabHeightArray[1] != null)
	{
		document.getElementById("spunit").style.setProperty("height",moreContentObj.tabHeightArray[1] + 5);
		button_bar.setBezelHeight(moreContentObj.tabHeightArray[1]);
	}
}

function alertsDataLoaded()
{
	activeAlertsNumber = parseInt(alertsDataObj.numberOfAlerts);
	alert_button_image.src = 'images/front/buttons/alerts/' + getAlertString() + '_nmo.png';
}

function getAlertString()
{
	if(activeAlertsNumber == 0)
		return 'off';
	else
		return 'on';
}
// Called when the search text is changed on the back of the widget.
function searchforcity (evt)
{
    if (evt.charCode == 13 || evt.charCode == 3) // Enter or return key?
    {
		startsearch(); // Begin searching
    }
    else // Change the glass button's action and text
    {
    	glassbutton._container.children[1].innerText = 'Search';
    	glassbutton.onclick = startsearch;
    	errormessage.innerText = "";
    	back_progress_animator.stop();
    }
}

// actually begins the search
function startsearch()
{
    if(stationsDataObj)
    {
    	cityMenu.disabled = true;
    	cityMenu.options.length = 0;
    	stationsMenu.disabled = true;
    	stationsMenu.options.length = 0;
    	glassbutton.onclick = searchforstation;
    	back_progress_animator.start();
    	errormessage.innerText = "Searching for cities...";
    	zipCodeField.value = zipCodeField.value.replace("<","").replace(">","");
		stationsDataObj.loadCities(escape(zipCodeField.value));
	}
	else
	{
		back_progress_animator.stop();
		errormessage.innerText = "Unable to connect to WeatherBug servers...";
    	glassbutton._container.children[1].innerText = 'Cancel';
  	 	glassbutton.onclick = switchFront;
  	 	if(back_stretch)
  	 	{
			back_stretch.changeHeight(85,null);
		}
	}
}

// begins a ststion cearch
function searchforstation ()
{
	back_progress_animator.start();
	errormessage.innerText = "Searching for stations...";
    glassbutton._container.children[1].innerText = 'Search';
    glassbutton.onclick = startsearch;
	stationsMenu.disabled = true;
	stationsMenu.options.length = 0;
	var str;
	
	if(stationsDataObj.cityTypeList[cityMenu.selectedIndex] == true)
	{
		str = '&cc=' + stationsDataObj.cityZipCodeList[cityMenu.selectedIndex];
	}
	else
	{
		str = '&zip=' + stationsDataObj.cityZipCodeList[cityMenu.selectedIndex];
	}
	stationsDataObj.loadStations(str);
}

// call back for successful city search
function citiesLoaded()
{
	back_progress_animator.stop();
	errormessage.innerText = "";
	back_stretch.changeHeight(125,null);
    if(cityMenu.options)
    {
    	delete cityMenu.options;
    }
    
	cityMenu.options = new Array();
	
	for (i=0; i < stationsDataObj.cityList.length; i++)
	{		
		cityMenu.options[i] = new Option(stationsDataObj.cityList[i],stationsDataObj.cityZipCodeList[i]);
	}
    cityMenu.disabled = false;
    stationsMenu.disabled = true;
    stationsMenu.options.length = 0;
	if(stationsDataObj.cityList.length == 1)
	{
		searchforstation();
	}
}

// callback for unsuccessful cities loaded
function citiesLoadedError()
{
	back_stretch.changeHeight(85,null);
	back_progress_animator.stop();
	errormessage.innerText = "No Cities Found";
    glassbutton._container.children[1].innerText = 'Cancel';
    glassbutton.onclick = switchFront;
}

// callback for successful station search
function stationsLoaded()
{
	back_progress_animator.stop();
	errormessage.innerText = "";
    if(stationsMenu.options)
    {
    	delete stationsMenu.options;
	}
	
	stationsMenu.options = new Array();

	for (i=0; i < stationsDataObj.stationsList.length; i++)
	{		
		stationsMenu.options[i] = new Option(stationsDataObj.stationsList[i],stationsDataObj.stationCodes[i+1]);
	}
	stationsMenu.disabled = false;
	glassbutton._container.children[1].innerText = 'Save';
	glassbutton.onclick = shrinkBack;
	back_stretch.changeHeight(165,null);
}

// callback for unsuccessful station loading
function stationsLoadedError()
{
	back_stretch.changeHeight(125,null);
	back_progress_animator.stop();
	errormessage.innerText = "No Stations Found";
	glassbutton._container.children[1].innerText = 'Cancel';
	glassbutton.onclick = switchFront;
}

// Called when the 'Location' button is clicked
function clickLocation()
{
	back_button_bar.clickLocation();
}

// Called when the 'Advanced' button is clicked
function clickAdvanced()
{
	back_button_bar.clickAdvanced();
}

// Called when the 'Contact_Us' button is clicked
function clickContact_Us()
{
	back_button_bar.clickContact_Us();
}

// funciton for opening a URL in a browser window (Safari, Firefox, ...)
function openWBugURL(num)
{
	if(num == '002' && activeAlertsNumber == 0)
	{
		num = '003';
	}
	else if(num == '409')
	{
		num = '409&ss=' + escape(document.getElementById('searchstring').value);
	}
	else if(num == '303')
	{
		num = '303&nextcamid=' + cameraDataObj.nextCamId;
	}

	var url = design.linkRedirectURL;

	if(window.widget)
	{
		url = url + "?LinkId=" + num + "&uid=" + widgetPrefs.getGUID() + "&version=" + version + "&zcode=" + ZCode + "&unittype=" + widgetPrefs.getUnits();
		if(widgetPrefs.getType() == true)
		{
			url = url + "&cc=" + widgetPrefs.getZipCode() + "&stat=" + widgetPrefs.getStationID();
		}
		else
		{
			url = url + "&zip=" + widgetPrefs.getZipCode() + "&stat=" + widgetPrefs.getStationID();
		}
		if (widgetPrefs.getType() == true)
		{
			if(num != '001' && num != '002' && num != '003')
				widget.openURL(url);
		}
		else
		{
			widget.openURL(url);
		}
	}
}

// function called when the dashboard interface is shown
function onShow()
{
	dashHidden = false;
	if(bugStateObj)
	{
		bugStateObj.setActiveReload(true);
	}
	else
	{
		design.load();
	}
}

// function called when the dashboard interface is hidden
function onHide()
{
	dashHidden = true;
	if(bugStateObj)
	{
		bugStateObj.setNoReload();
	}
}

// generic error callback for common data errors
function dataLoadingError(str,time)
{
	alert("WeatherBug Local Weather Error -- Unable To Load Data");
	alert(str);
	alert(time);
	setTimeout(str,time);
}

function clearInterface()
{
	temperature_text.innerHTML = "--";
	windspeed_label.innerHTML= "--";
	windspeed_magnitude.innerHTML = "--";

	currenttitle.innerHTML = "";
	fconetitle.innerHTML = "--";
	fctwotitle.innerHTML = "--";
	fcthreetitle.innerHTML = "--";
	
	fccurrentimg.src = 'images/front/other/fcloading.png';
	fconeimage.src = 'images/front/other/fcloading.png';
	fctwoimage.src = 'images/front/other/fcloading.png';
	fcthreeimage.src = 'images/front/other/fcloading.png';

	currenthitemp.innerHTML = "Hi: --&deg;";
	currentlowtemp.innerHTML = "Lo: --&deg;";
	fconehigh.innerHTML = '--&deg;';
	fctwohigh.innerHTML = '--&deg;';
	fcthreehigh.innerHTML = '--&deg;';

	fconelow.innerHTML = '--&deg;';
	fctwolow.innerHTML = '--&deg;';
	fcthreelow.innerHTML = '--&deg;';
	document.getElementById('radar_image').src = 'images/front/other/fcloadinglarge.png';
	//button_bar.setAlertsButtonSource(widgetPrefs.getType(),false);
	document.getElementById("spunit").style.setProperty("height",0);
	button_bar.setBezelHeight(0);
}

function toggleTitle()
{
	if(widgetPrefs.getType() == true)
	{
		if(widgetPrefs.getStationOrLocation() == true)
		{
			location_text.innerHTML = "<IMG SRC='images/front/other/triangle.png' WIDTH=5 HEIGHT=8> " + liveDataObj.source;
			widgetPrefs.setStationOrLocation(false);
		}
		else
		{
			location_text.innerHTML = "<IMG SRC='images/front/other/triangle.png' WIDTH=5 HEIGHT=8> " + liveDataObj.location;
			widgetPrefs.setStationOrLocation(true);
		}
	}
	else
	{
		if(widgetPrefs.getStationOrLocation() == true)
		{
			location_text.innerHTML = "<IMG SRC='images/front/other/triangle.png' WIDTH=5 HEIGHT=8> " + liveDataObj.source + " (" + widgetPrefs.getZipCode() + ")";
			widgetPrefs.setStationOrLocation(false);
		}
		else
		{
			location_text.innerHTML = "<IMG SRC='images/front/other/triangle.png' WIDTH=5 HEIGHT=8> " + liveDataObj.location + " (" + widgetPrefs.getZipCode() + ")";
			widgetPrefs.setStationOrLocation(true);
		}	
	}
}

function cameraDataLoaded()
{
	cam_image.src = cameraDataObj.mainCameraSource;
	cam_thumb.src = cameraDataObj.cameraThumbSource;
}

// liveDataObj Successful Load Callback
function liveDataLoaded()
{
	vaneObj.changePosition(liveDataObj.winddirection);
	if(widgetPrefs.getType() == true)
	{
		if(widgetPrefs.getStationOrLocation() == true)
		{
			location_text.innerHTML = "<IMG SRC='images/front/other/triangle.png' WIDTH=5 HEIGHT=8> " + liveDataObj.location;
		}
		else
		{
			location_text.innerHTML = "<IMG SRC='images/front/other/triangle.png' WIDTH=5 HEIGHT=8> " + liveDataObj.source;
		}
	}
	else
	{
		if(widgetPrefs.getStationOrLocation() == true)
		{
			location_text.innerHTML = "<IMG SRC='images/front/other/triangle.png' WIDTH=5 HEIGHT=8> " + liveDataObj.location + " (" + widgetPrefs.getZipCode() + ")";
		}
		else
		{
			location_text.innerHTML = "<IMG SRC='images/front/other/triangle.png' WIDTH=5 HEIGHT=8> " + liveDataObj.source + " (" + widgetPrefs.getZipCode() + ")";
		}	
	}

	if(widgetPrefs.getUnits() == 0)
	{
		temperature_text.innerHTML = liveDataObj.temperature + "&deg;F";
		windspeed_label.innerHTML= "mph";
	}
	else
	{
		temperature_text.innerHTML = liveDataObj.temperature + "&deg;C";
		windspeed_label.innerHTML= "kph";
	}
	
	windspeed_magnitude.innerHTML = liveDataObj.windspeed;
}

// forecastDataObj Successful Load Callback
function forecastDataLoaded()
{
	document.getElementById("fcthumb").src = forecastDataObj.fcthumb;
	
	var i;
	for(i=0;i<6;i++)
	{
		if(forecastDataObj.imageArray[i] == null)
			forecastDataObj.imageArray[i] = 'blank.png';

		if(forecastDataObj.highArray[i] == null)
			forecastDataObj.highArray[i] = '--';

		if(forecastDataObj.lowArray[i] == null)
			forecastDataObj.lowArray[i] = '--';
			
		if(forecastDataObj.titleArray[i] == null)
			forecastDataObj.titleArray[i] = '--';
	}
	
	currenttitle.innerHTML = forecastDataObj.titleArray[0] + "'s Forecast";
	fccurrentimg.src = 'images/front/other/forecasticons/' + forecastDataObj.imageArray[0];
	currenthitemp.innerHTML = "Hi: " + forecastDataObj.highArray[0] + '&deg;';
	currentlowtemp.innerHTML = "Lo: " + forecastDataObj.lowArray[0] + '&deg;';
	
	if(widgetPrefs.getType() == true)
	{		
		fconetitle.innerHTML = forecastDataObj.titleArray[1];
		fconeimage.src = 'images/front/other/forecasticons/' + forecastDataObj.imageArray[1];
		fconehigh.innerHTML = forecastDataObj.highArray[1] + '&deg;';
		fconelow.innerHTML = forecastDataObj.lowArray[1] + '&deg;';
		
		fctwotitle.innerHTML = forecastDataObj.titleArray[2];
		fctwoimage.src = "images/front/other/forecasticons/" + forecastDataObj.imageArray[2];
		fctwohigh.innerHTML = forecastDataObj.highArray[2] + '&deg;';
		fctwolow.innerHTML = forecastDataObj.lowArray[2] + '&deg;';
		
		if(forecastDataObj.numOfBlocks == 2)
		{

			fcbg.src = 'images/front/drawer/forecast/background2.png';
			document.getElementById("fcthree").style.setProperty("opacity","0");
			document.getElementById("morelinkthree").style.setProperty("opacity","0");
			document.getElementById("fcone").style.setProperty("left","15");
			document.getElementById("fctwo").style.setProperty("left","105");
		}
		else
		{
			fcbg.src = 'images/front/drawer/forecast/background.png';
			fcthreetitle.innerHTML = forecastDataObj.titleArray[3];
			fcthreeimage.src = 'images/front/other/forecasticons/' + forecastDataObj.imageArray[3];
			fcthreehigh.innerHTML = forecastDataObj.highArray[3] + '&deg;';
			fcthreelow.innerHTML = forecastDataObj.lowArray[3] + '&deg;';
			document.getElementById("fcthree").style.setProperty("opacity","1");
			document.getElementById("morelinkthree").style.setProperty("opacity","1");
			document.getElementById("fcone").style.setProperty("left","0");
			document.getElementById("fctwo").style.setProperty("left","60");
		}
	}
	else
	{
		fconetitle.innerHTML = forecastDataObj.titleArray[1];
		fconeimage.src = 'images/front/other/forecasticons/' + forecastDataObj.imageArray[1];
		fconehigh.innerHTML = forecastDataObj.highArray[1] + '&deg;';
		fconelow.innerHTML = forecastDataObj.lowArray[1] + '&deg;';
		
		fctwotitle.innerHTML = forecastDataObj.titleArray[2];
		fctwoimage.src = 'images/front/other/forecasticons/' + forecastDataObj.imageArray[2];
		fctwohigh.innerHTML = forecastDataObj.highArray[2] + '&deg;';
		fctwolow.innerHTML = forecastDataObj.lowArray[2] + '&deg;';
		
		
		fcthreetitle.innerHTML = forecastDataObj.titleArray[3];
		fcthreeimage.src = 'images/front/other/forecasticons/' + forecastDataObj.imageArray[3];
		fcthreehigh.innerHTML = forecastDataObj.highArray[3] + '&deg;';
		fcthreelow.innerHTML = forecastDataObj.lowArray[3] + '&deg;';
	}
}

// radarDataObj Successful Load Callback
function radarDataLoaded()
{
	document.getElementById('radar_image').src = radarDataObj.imgSrc;
	document.getElementById('rdrthumb').src = radarDataObj.thumbSrc;
}

// Used by the widget to close the drawer before a transition to the prefereces back
function shrinkAndShowBack()
{
	if(!drawer_stretch.isNotStretched())
	{
		button_bar.showBack = true;
		drawer_stretch.onFinished = function () {
			button_bar.showBack = false;
			this.object.drawer_element.style.setProperty("opacity","0");
			setNullAndShowBack();
		};
		button_bar.drawerClose();
	}
	else
	{
		showBack();
	}
}

// Sets the drawer callback to null, then shows the widget back
function setNullAndShowBack()
{
	drawer_stretch.onFinished = null;
	showBack();
}

// Function to handle widget transition from front to back. 'event' is a passed mouse event.
function showBack(event)
{
	if(bugStateObj){
		bugStateObj.setNoReload();
	}
	document.getElementById('front').style.display="none";
	document.getElementById('back').style.display="block";
	if(!back_stretch){
		back_stretch = new WBDrawer(document.getElementById('back'),500);// The expanding drawer element of the widget
	}
	if(!back_button_bar){
		back_button_bar = new WBThreeButtonBar(document.getElementById('back_location_container'),back_location_image,document.getElementById('back_advanced_container'),back_advanced_image,document.getElementById('back_contact_us_container'),back_contact_us_image,back_stretch);
	}
	if(!glassbutton){
		glassbutton = new AppleGlassButton(document.getElementById("doneButton"), "Save", shrinkBack);// "Save" button on the preferences side of the widget
	}
	if(!back_progress_animator){
		back_progress_animator = new WBProgressAnimator(document.getElementById('progress_wheel'),8,70,'images/back/progress');
	}
	if(widgetPrefs.getType() == true){
		if(widget.preferenceForKey(forWidgetInstance('countryName'))){
			zipCodeField.value = widget.preferenceForKey(forWidgetInstance('countryName'));
		}	
	}
	else{
		if(widget.preferenceForKey(forWidgetInstance('zipCode'))){
			zipCodeField.value = widget.preferenceForKey(forWidgetInstance('zipCode'));
		}
	}
	document.getElementById("updateCB").checked = widgetPrefs.getNotifyForUpdates();
	if(widgetPrefs.getUnits() == true)
	{
		document.getElementById("unitsMenu").selectedIndex = 1;
	}
	else
	{
		document.getElementById("unitsMenu").selectedIndex = 0;
	}
	if (window.widget){
		widget.prepareForTransition("ToBack");
		setTimeout("widget.performTransition();", 0);
		setTimeout("widget.setCloseBoxOffset(3,25);",1000);
		if(design.newVersionAvailable == 1 && notifiedofupdate == false && widgetPrefs.getNotifyForUpdates() == true){
			setTimeout("back_button_bar.clickAdvanced();",1000);
		}
		else{
			setTimeout("back_button_bar.clickLocation();",1000);
		}
		
	}
	exitflip(event);
}

var flipShown = false; 
var animation = {duration:0, starttime:0, to:1.0, now:0.0, from:0.0, firstElement:null, timer:null};

function mousemove(event)
{ 
    if (!flipShown) 
    {
    	if(bugStateObj && !bugStateObj.state) { bugStateObj.setActiveReload(true); }
        if (animation.timer != null) 
        { 
            clearInterval (animation.timer); 
            animation.timer  = null; 
        } 
        var starttime = (new Date).getTime() - 13; 
        animation.duration = 500;
        animation.starttime = starttime; 
        animation.firstElement = document.getElementById ('flip'); 
        animation.timer = setInterval ("animate();", 13); 
        animation.from = animation.now; 
        animation.to = 1.0;
        animate(); 
        flipShown = true; 
    } 
} 

function mouseexit(event) 
{ 
    if (flipShown) 
    {
    	if(bugStateObj) { bugStateObj.setActiveReload(true); } 
        // fade in the info button 
        if (animation.timer != null) 
        { 
            clearInterval (animation.timer); 
            animation.timer  = null; 
        } 
        var starttime = (new Date).getTime() - 13; 
        animation.duration = 500; 
        animation.starttime = starttime; 
        animation.firstElement = document.getElementById ('flip'); 
        animation.timer = setInterval ("animate();", 13); 
        animation.from = animation.now; 
        animation.to = 0.0; 
        animate(); 
        flipShown = false; 
    } 
}

function animate() 
{ 
    var T; 
    var ease; 
    var time = (new Date).getTime(); 
    T = limit_3(time-animation.starttime, 0, animation.duration); 
    if (T >= animation.duration) 
    { 
        clearInterval (animation.timer); 
        animation.timer = null; 
        animation.now = animation.to; 
    } 
    else 
    { 
        ease = 0.5 - (0.5 * Math.cos(Math.PI * T / animation.duration)); 
        animation.now = computeNextFloat (animation.from, animation.to, ease); 
    } 
    animation.firstElement.style.opacity = animation.now; 
} 

function limit_3 (a, b, c) 
{ 
    return a < b ? b : (a > c ? c : a); 
} 

function computeNextFloat (from, to, ease) 
{ 
    return from + (to - from) * ease; 
}

function enterflip(event) 
{ 
    document.getElementById('fliprollie').style.display = 'block'; 
} 

function exitflip(event) 
{ 
	document.getElementById('fliprollie').style.display = 'none';
}
// End Code For Widget Flip


// shrinks the back of the widget to the normal height before transitioning to the front
function shrinkBack ()
{
	back_button_bar.closeDrawer(hideBack);
}

// sets the preferences if they exist, and then hides the widget
function hideBack() {
	switchFront();
}

// Transitions from the back interface to the front
function switchFront()
{
	errormessage.innerText = "";
	back_progress_animator.stop();
	glassbutton._container.children[1].innerText = 'Save';
	glassbutton.onclick = shrinkBack;
	document.getElementById('back').style.display="none";
	document.getElementById('front').style.display="block";

	if (window.widget) {
		widget.prepareForTransition("ToFront");
	}

	if (window.widget) {
		setTimeout("widget.performTransition()", 0);
		setTimeout ("clearInterface();design.load();widget.setCloseBoxOffset(3,15);",500);
	}
}

// XML parsing function
function findChild (element, nodeName)
{
	var child;
	
	for (child = element.firstChild; child != null; child = child.nextSibling)
	{
		if (child.nodeName == nodeName)
			return child;
	}
	return null;
}

function forWidgetInstance(str)
{
	return (widget.identifier + "-" + str);
}